@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2006 Edgewall Software
+# Copyright (C) 2006-2013 Edgewall Software
 # All rights reserved.
 #
 # This software is licensed as described in the file COPYING, which
@@ -15,13 +15,14 @@ import doctest
 import unittest
 from StringIO import StringIO
 
+import trac.tests.compat
 from trac.core import *
 from trac.test import EnvironmentStub
 from trac.mimeview import api
 from trac.mimeview.api import get_mimetype, IContentConverter, Mimeview, \
                               _group_lines
 from genshi import Stream, Namespace
-from genshi.core import Attrs, TEXT, START, END, START_NS, END_NS
+from genshi.core import Attrs, TEXT, START, END
 from genshi.input import HTMLParser
 
 
@@ -30,11 +31,11 @@ class GetMimeTypeTestCase(unittest.TestCase):
     def test_from_suffix_using_MIME_MAP(self):
         self.assertEqual('text/plain', get_mimetype('README', None))
         self.assertEqual('text/plain', get_mimetype('README.txt', None))
-        
+
     def test_from_suffix_using_mimetypes(self):
-        self.assertEqual('image/png',
-                         get_mimetype('doc/trac_logo.png', None))
-        
+        accepted = ('image/png', 'image/x-png')
+        self.assertTrue(get_mimetype('doc/trac_logo.png', None) in accepted)
+
     def test_from_content_using_CONTENT_RE(self):
         self.assertEqual('text/x-python',
                          get_mimetype('xxx', """
@@ -72,18 +73,12 @@ class GetMimeTypeTestCase(unittest.TestCase):
 class MimeviewTestCase(unittest.TestCase):
 
     def setUp(self):
-        self.env = EnvironmentStub(default_data=True)
-
-        # Make sure we have no external components hanging around in the
-        # component registry
-        from trac.core import ComponentMeta
-        self.old_registry = ComponentMeta._registry
-        ComponentMeta._registry = {}
+        self.env = EnvironmentStub(default_data=False,
+            enable=['%s.%s' % (self.__module__, c)
+                    for c in ['Converter0', 'Converter1', 'Converter2']])
 
     def tearDown(self):
-        # Restore the original component registry
-        from trac.core import ComponentMeta
-        ComponentMeta._registry = self.old_registry
+        pass
 
     def test_get_supported_conversions(self):
         class Converter0(Component):
@@ -117,22 +112,22 @@ class GroupLinesTestCase(unittest.TestCase):
     def test_text_only_stream(self):
         input = [(TEXT, "test", (None, -1, -1))]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), 1)
-        self.assertTrue(isinstance(lines[0], Stream))
-        self.assertEquals(lines[0].events, input)
+        self.assertEqual(len(lines), 1)
+        self.assertIsInstance(lines[0], Stream)
+        self.assertEqual(lines[0].events, input)
 
     def test_text_only_stream2(self):
         input = [(TEXT, "test\n", (None, -1, -1))]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), 1)
-        self.assertTrue(isinstance(lines[0], Stream))
-        self.assertEquals(lines[0].events, [(TEXT, "test", (None, -1, -1))])
+        self.assertEqual(len(lines), 1)
+        self.assertIsInstance(lines[0], Stream)
+        self.assertEqual(lines[0].events, [(TEXT, "test", (None, -1, -1))])
 
     def test_simplespan(self):
-        input = HTMLParser(StringIO("<span>test</span>"))
+        input = HTMLParser(StringIO(u"<span>test</span>"), encoding=None)
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), 1)
-        self.assertTrue(isinstance(lines[0], Stream))
+        self.assertEqual(len(lines), 1)
+        self.assertIsInstance(lines[0], Stream)
         for (a, b) in zip(lines[0], input):
             self.assertEqual(a, b)
 
@@ -142,17 +137,17 @@ class GroupLinesTestCase(unittest.TestCase):
         """
         input = [(TEXT, "", (None, -1, -1))]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), 0)
+        self.assertEqual(len(lines), 0)
 
     def test_newline_stream(self):
         input = [(TEXT, "\n", (None, -1, -1))]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), 1)
+        self.assertEqual(len(lines), 1)
 
     def test_newline_stream2(self):
         input = [(TEXT, "\n\n\n", (None, -1, -1))]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), 3)
+        self.assertEqual(len(lines), 3)
 
     def test_empty_text_in_span(self):
         """
@@ -165,57 +160,60 @@ class GroupLinesTestCase(unittest.TestCase):
                 ]
         lines = list(_group_lines(input))
         self.assertEqual(len(lines), 0)
-                 
+
     def test_newline(self):
         """
         If the text element does not end with a newline, it's not properly
         closed.
         """
-        input = HTMLParser(StringIO('<span class="c">a\nb</span>'))
+        input = HTMLParser(StringIO(u'<span class="c">a\nb</span>'),
+            encoding=None)
         expected = ['<span class="c">a</span>',
                     '<span class="c">b</span>',
                    ]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), len(expected))
+        self.assertEqual(len(lines), len(expected))
         for a, b in zip(lines, expected):
-            self.assertEquals(a.render('html'), b)
+            self.assertEqual(a.render('html'), b)
 
     def test_newline2(self):
         """
         Same as test_newline above, but make sure it behaves properly wrt
         the trailing \\n, especially given it's inside an element.
         """
-        input = HTMLParser(StringIO('<span class="c">a\nb\n</span>'))
+        input = HTMLParser(StringIO(u'<span class="c">a\nb\n</span>'),
+            encoding=None)
         expected = ['<span class="c">a</span>',
                     '<span class="c">b</span>',
                    ]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), len(expected))
+        self.assertEqual(len(lines), len(expected))
         for a, b in zip(lines, expected):
-            self.assertEquals(a.render('html'), b)
+            self.assertEqual(a.render('html'), b)
 
     def test_multinewline(self):
         """
         ditto.
         """
-        input = HTMLParser(StringIO('<span class="c">\n\n\na</span>'))
+        input = HTMLParser(StringIO(u'<span class="c">\n\n\na</span>'),
+            encoding=None)
         expected = ['<span class="c"></span>',
                     '<span class="c"></span>',
                     '<span class="c"></span>',
                     '<span class="c">a</span>',
                    ]
         lines = list(_group_lines(input))
-        self.assertEquals(len(lines), len(expected))
+        self.assertEqual(len(lines), len(expected))
         for a, b in zip(lines, expected):
-            self.assertEquals(a.render('html'), b)
+            self.assertEqual(a.render('html'), b)
 
 
 def suite():
     suite = unittest.TestSuite()
     suite.addTest(doctest.DocTestSuite(api))
-    suite.addTest(unittest.makeSuite(GetMimeTypeTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(MimeviewTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(GroupLinesTestCase, 'test'))
+    suite.addTest(unittest.makeSuite(GetMimeTypeTestCase))
+    suite.addTest(unittest.makeSuite(MimeviewTestCase))
+    suite.addTest(unittest.makeSuite(GroupLinesTestCase))
     return suite
 
 if __name__ == '__main__':
